Class: Aws::WorkMail::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::WorkMail::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-workmail/client.rb,
sig/client.rbs
Overview
An API client for WorkMail. To construct a client, you need to configure a :region and :credentials.
client = Aws::WorkMail::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _AssociateDelegateToResourceResponseSuccess, _AssociateMemberToGroupResponseSuccess, _AssumeImpersonationRoleResponseSuccess, _CancelMailboxExportJobResponseSuccess, _CreateAliasResponseSuccess, _CreateAvailabilityConfigurationResponseSuccess, _CreateGroupResponseSuccess, _CreateIdentityCenterApplicationResponseSuccess, _CreateImpersonationRoleResponseSuccess, _CreateMobileDeviceAccessRuleResponseSuccess, _CreateOrganizationResponseSuccess, _CreateResourceResponseSuccess, _CreateUserResponseSuccess, _DeleteAccessControlRuleResponseSuccess, _DeleteAliasResponseSuccess, _DeleteAvailabilityConfigurationResponseSuccess, _DeleteEmailMonitoringConfigurationResponseSuccess, _DeleteGroupResponseSuccess, _DeleteIdentityCenterApplicationResponseSuccess, _DeleteIdentityProviderConfigurationResponseSuccess, _DeleteImpersonationRoleResponseSuccess, _DeleteMailboxPermissionsResponseSuccess, _DeleteMobileDeviceAccessOverrideResponseSuccess, _DeleteMobileDeviceAccessRuleResponseSuccess, _DeleteOrganizationResponseSuccess, _DeletePersonalAccessTokenResponseSuccess, _DeleteResourceResponseSuccess, _DeleteRetentionPolicyResponseSuccess, _DeleteUserResponseSuccess, _DeregisterFromWorkMailResponseSuccess, _DeregisterMailDomainResponseSuccess, _DescribeEmailMonitoringConfigurationResponseSuccess, _DescribeEntityResponseSuccess, _DescribeGroupResponseSuccess, _DescribeIdentityProviderConfigurationResponseSuccess, _DescribeInboundDmarcSettingsResponseSuccess, _DescribeMailboxExportJobResponseSuccess, _DescribeOrganizationResponseSuccess, _DescribeResourceResponseSuccess, _DescribeUserResponseSuccess, _DisassociateDelegateFromResourceResponseSuccess, _DisassociateMemberFromGroupResponseSuccess, _GetAccessControlEffectResponseSuccess, _GetDefaultRetentionPolicyResponseSuccess, _GetImpersonationRoleEffectResponseSuccess, _GetImpersonationRoleResponseSuccess, _GetMailDomainResponseSuccess, _GetMailboxDetailsResponseSuccess, _GetMobileDeviceAccessEffectResponseSuccess, _GetMobileDeviceAccessOverrideResponseSuccess, _GetPersonalAccessTokenMetadataResponseSuccess, _ListAccessControlRulesResponseSuccess, _ListAliasesResponseSuccess, _ListAvailabilityConfigurationsResponseSuccess, _ListGroupMembersResponseSuccess, _ListGroupsForEntityResponseSuccess, _ListGroupsResponseSuccess, _ListImpersonationRolesResponseSuccess, _ListMailDomainsResponseSuccess, _ListMailboxExportJobsResponseSuccess, _ListMailboxPermissionsResponseSuccess, _ListMobileDeviceAccessOverridesResponseSuccess, _ListMobileDeviceAccessRulesResponseSuccess, _ListOrganizationsResponseSuccess, _ListPersonalAccessTokensResponseSuccess, _ListResourceDelegatesResponseSuccess, _ListResourcesResponseSuccess, _ListTagsForResourceResponseSuccess, _ListUsersResponseSuccess, _PutAccessControlRuleResponseSuccess, _PutEmailMonitoringConfigurationResponseSuccess, _PutIdentityProviderConfigurationResponseSuccess, _PutInboundDmarcSettingsResponseSuccess, _PutMailboxPermissionsResponseSuccess, _PutMobileDeviceAccessOverrideResponseSuccess, _PutRetentionPolicyResponseSuccess, _RegisterMailDomainResponseSuccess, _RegisterToWorkMailResponseSuccess, _ResetPasswordResponseSuccess, _StartMailboxExportJobResponseSuccess, _TagResourceResponseSuccess, _TestAvailabilityConfigurationResponseSuccess, _UntagResourceResponseSuccess, _UpdateAvailabilityConfigurationResponseSuccess, _UpdateDefaultMailDomainResponseSuccess, _UpdateGroupResponseSuccess, _UpdateImpersonationRoleResponseSuccess, _UpdateMailboxQuotaResponseSuccess, _UpdateMobileDeviceAccessRuleResponseSuccess, _UpdatePrimaryEmailAddressResponseSuccess, _UpdateResourceResponseSuccess, _UpdateUserResponseSuccess
Constant Summary collapse
- Params =
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_delegate_to_resource(params = {}) ⇒ Struct
Adds a member (user or group) to the resource's set of delegates.
-
#associate_member_to_group(params = {}) ⇒ Struct
Adds a member (user or group) to the group's set.
-
#assume_impersonation_role(params = {}) ⇒ Types::AssumeImpersonationRoleResponse
Assumes an impersonation role for the given WorkMail organization.
-
#cancel_mailbox_export_job(params = {}) ⇒ Struct
Cancels a mailbox export job.
-
#create_alias(params = {}) ⇒ Struct
Adds an alias to the set of a given member (user or group) of WorkMail.
-
#create_availability_configuration(params = {}) ⇒ Struct
Creates an
AvailabilityConfigurationfor the given WorkMail organization and domain. -
#create_group(params = {}) ⇒ Types::CreateGroupResponse
Creates a group that can be used in WorkMail by calling the RegisterToWorkMail operation.
-
#create_identity_center_application(params = {}) ⇒ Types::CreateIdentityCenterApplicationResponse
Creates the WorkMail application in IAM Identity Center that can be used later in the WorkMail - IdC integration.
-
#create_impersonation_role(params = {}) ⇒ Types::CreateImpersonationRoleResponse
Creates an impersonation role for the given WorkMail organization.
-
#create_mobile_device_access_rule(params = {}) ⇒ Types::CreateMobileDeviceAccessRuleResponse
Creates a new mobile device access rule for the specified WorkMail organization.
-
#create_organization(params = {}) ⇒ Types::CreateOrganizationResponse
Creates a new WorkMail organization.
-
#create_resource(params = {}) ⇒ Types::CreateResourceResponse
Creates a new WorkMail resource.
-
#create_user(params = {}) ⇒ Types::CreateUserResponse
Creates a user who can be used in WorkMail by calling the RegisterToWorkMail operation.
-
#delete_access_control_rule(params = {}) ⇒ Struct
Deletes an access control rule for the specified WorkMail organization.
-
#delete_alias(params = {}) ⇒ Struct
Remove one or more specified aliases from a set of aliases for a given user.
-
#delete_availability_configuration(params = {}) ⇒ Struct
Deletes the
AvailabilityConfigurationfor the given WorkMail organization and domain. -
#delete_email_monitoring_configuration(params = {}) ⇒ Struct
Deletes the email monitoring configuration for a specified organization.
-
#delete_group(params = {}) ⇒ Struct
Deletes a group from WorkMail.
-
#delete_identity_center_application(params = {}) ⇒ Struct
Deletes the IAM Identity Center application from WorkMail.
-
#delete_identity_provider_configuration(params = {}) ⇒ Struct
Disables the integration between IdC and WorkMail.
-
#delete_impersonation_role(params = {}) ⇒ Struct
Deletes an impersonation role for the given WorkMail organization.
-
#delete_mailbox_permissions(params = {}) ⇒ Struct
Deletes permissions granted to a member (user or group).
-
#delete_mobile_device_access_override(params = {}) ⇒ Struct
Deletes the mobile device access override for the given WorkMail organization, user, and device.
-
#delete_mobile_device_access_rule(params = {}) ⇒ Struct
Deletes a mobile device access rule for the specified WorkMail organization.
-
#delete_organization(params = {}) ⇒ Types::DeleteOrganizationResponse
Deletes an WorkMail organization and all underlying AWS resources managed by WorkMail as part of the organization.
-
#delete_personal_access_token(params = {}) ⇒ Struct
Deletes the Personal Access Token from the provided WorkMail Organization.
-
#delete_resource(params = {}) ⇒ Struct
Deletes the specified resource.
-
#delete_retention_policy(params = {}) ⇒ Struct
Deletes the specified retention policy from the specified organization.
-
#delete_user(params = {}) ⇒ Struct
Deletes a user from WorkMail and all subsequent systems.
-
#deregister_from_work_mail(params = {}) ⇒ Struct
Mark a user, group, or resource as no longer used in WorkMail.
-
#deregister_mail_domain(params = {}) ⇒ Struct
Removes a domain from WorkMail, stops email routing to WorkMail, and removes the authorization allowing WorkMail use.
-
#describe_email_monitoring_configuration(params = {}) ⇒ Types::DescribeEmailMonitoringConfigurationResponse
Describes the current email monitoring configuration for a specified organization.
-
#describe_entity(params = {}) ⇒ Types::DescribeEntityResponse
Returns basic details about an entity in WorkMail.
-
#describe_group(params = {}) ⇒ Types::DescribeGroupResponse
Returns the data available for the group.
-
#describe_identity_provider_configuration(params = {}) ⇒ Types::DescribeIdentityProviderConfigurationResponse
Returns detailed information on the current IdC setup for the WorkMail organization.
-
#describe_inbound_dmarc_settings(params = {}) ⇒ Types::DescribeInboundDmarcSettingsResponse
Lists the settings in a DMARC policy for a specified organization.
-
#describe_mailbox_export_job(params = {}) ⇒ Types::DescribeMailboxExportJobResponse
Describes the current status of a mailbox export job.
-
#describe_organization(params = {}) ⇒ Types::DescribeOrganizationResponse
Provides more information regarding a given organization based on its identifier.
-
#describe_resource(params = {}) ⇒ Types::DescribeResourceResponse
Returns the data available for the resource.
-
#describe_user(params = {}) ⇒ Types::DescribeUserResponse
Provides information regarding the user.
-
#disassociate_delegate_from_resource(params = {}) ⇒ Struct
Removes a member from the resource's set of delegates.
-
#disassociate_member_from_group(params = {}) ⇒ Struct
Removes a member from a group.
-
#get_access_control_effect(params = {}) ⇒ Types::GetAccessControlEffectResponse
Gets the effects of an organization's access control rules as they apply to a specified IPv4 address, access protocol action, and user ID or impersonation role ID.
-
#get_default_retention_policy(params = {}) ⇒ Types::GetDefaultRetentionPolicyResponse
Gets the default retention policy details for the specified organization.
-
#get_impersonation_role(params = {}) ⇒ Types::GetImpersonationRoleResponse
Gets the impersonation role details for the given WorkMail organization.
-
#get_impersonation_role_effect(params = {}) ⇒ Types::GetImpersonationRoleEffectResponse
Tests whether the given impersonation role can impersonate a target user.
-
#get_mail_domain(params = {}) ⇒ Types::GetMailDomainResponse
Gets details for a mail domain, including domain records required to configure your domain with recommended security.
-
#get_mailbox_details(params = {}) ⇒ Types::GetMailboxDetailsResponse
Requests a user's mailbox details for a specified organization and user.
-
#get_mobile_device_access_effect(params = {}) ⇒ Types::GetMobileDeviceAccessEffectResponse
Simulates the effect of the mobile device access rules for the given attributes of a sample access event.
-
#get_mobile_device_access_override(params = {}) ⇒ Types::GetMobileDeviceAccessOverrideResponse
Gets the mobile device access override for the given WorkMail organization, user, and device.
-
#get_personal_access_token_metadata(params = {}) ⇒ Types::GetPersonalAccessTokenMetadataResponse
Requests details of a specific Personal Access Token within the WorkMail organization.
-
#list_access_control_rules(params = {}) ⇒ Types::ListAccessControlRulesResponse
Lists the access control rules for the specified organization.
-
#list_aliases(params = {}) ⇒ Types::ListAliasesResponse
Creates a paginated call to list the aliases associated with a given entity.
-
#list_availability_configurations(params = {}) ⇒ Types::ListAvailabilityConfigurationsResponse
List all the
AvailabilityConfiguration's for the given WorkMail organization. -
#list_group_members(params = {}) ⇒ Types::ListGroupMembersResponse
Returns an overview of the members of a group.
-
#list_groups(params = {}) ⇒ Types::ListGroupsResponse
Returns summaries of the organization's groups.
-
#list_groups_for_entity(params = {}) ⇒ Types::ListGroupsForEntityResponse
Returns all the groups to which an entity belongs.
-
#list_impersonation_roles(params = {}) ⇒ Types::ListImpersonationRolesResponse
Lists all the impersonation roles for the given WorkMail organization.
-
#list_mail_domains(params = {}) ⇒ Types::ListMailDomainsResponse
Lists the mail domains in a given WorkMail organization.
-
#list_mailbox_export_jobs(params = {}) ⇒ Types::ListMailboxExportJobsResponse
Lists the mailbox export jobs started for the specified organization within the last seven days.
-
#list_mailbox_permissions(params = {}) ⇒ Types::ListMailboxPermissionsResponse
Lists the mailbox permissions associated with a user, group, or resource mailbox.
-
#list_mobile_device_access_overrides(params = {}) ⇒ Types::ListMobileDeviceAccessOverridesResponse
Lists all the mobile device access overrides for any given combination of WorkMail organization, user, or device.
-
#list_mobile_device_access_rules(params = {}) ⇒ Types::ListMobileDeviceAccessRulesResponse
Lists the mobile device access rules for the specified WorkMail organization.
-
#list_organizations(params = {}) ⇒ Types::ListOrganizationsResponse
Returns summaries of the customer's organizations.
-
#list_personal_access_tokens(params = {}) ⇒ Types::ListPersonalAccessTokensResponse
Returns a summary of your Personal Access Tokens.
-
#list_resource_delegates(params = {}) ⇒ Types::ListResourceDelegatesResponse
Lists the delegates associated with a resource.
-
#list_resources(params = {}) ⇒ Types::ListResourcesResponse
Returns summaries of the organization's resources.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags applied to an WorkMail organization resource.
-
#list_users(params = {}) ⇒ Types::ListUsersResponse
Returns summaries of the organization's users.
-
#put_access_control_rule(params = {}) ⇒ Struct
Adds a new access control rule for the specified organization.
-
#put_email_monitoring_configuration(params = {}) ⇒ Struct
Creates or updates the email monitoring configuration for a specified organization.
-
#put_identity_provider_configuration(params = {}) ⇒ Struct
Enables integration between IAM Identity Center (IdC) and WorkMail to proxy authentication requests for mailbox users.
-
#put_inbound_dmarc_settings(params = {}) ⇒ Struct
Enables or disables a DMARC policy for a given organization.
-
#put_mailbox_permissions(params = {}) ⇒ Struct
Sets permissions for a user, group, or resource.
-
#put_mobile_device_access_override(params = {}) ⇒ Struct
Creates or updates a mobile device access override for the given WorkMail organization, user, and device.
-
#put_retention_policy(params = {}) ⇒ Struct
Puts a retention policy to the specified organization.
-
#register_mail_domain(params = {}) ⇒ Struct
Registers a new domain in WorkMail and SES, and configures it for use by WorkMail.
-
#register_to_work_mail(params = {}) ⇒ Struct
Registers an existing and disabled user, group, or resource for WorkMail use by associating a mailbox and calendaring capabilities.
-
#reset_password(params = {}) ⇒ Struct
Allows the administrator to reset the password for a user.
-
#start_mailbox_export_job(params = {}) ⇒ Types::StartMailboxExportJobResponse
Starts a mailbox export job to export MIME-format email messages and calendar items from the specified mailbox to the specified Amazon Simple Storage Service (Amazon S3) bucket.
-
#tag_resource(params = {}) ⇒ Struct
Applies the specified tags to the specified WorkMailorganization resource.
-
#test_availability_configuration(params = {}) ⇒ Types::TestAvailabilityConfigurationResponse
Performs a test on an availability provider to ensure that access is allowed.
-
#untag_resource(params = {}) ⇒ Struct
Untags the specified tags from the specified WorkMail organization resource.
-
#update_availability_configuration(params = {}) ⇒ Struct
Updates an existing
AvailabilityConfigurationfor the given WorkMail organization and domain. -
#update_default_mail_domain(params = {}) ⇒ Struct
Updates the default mail domain for an organization.
-
#update_group(params = {}) ⇒ Struct
Updates attributes in a group.
-
#update_impersonation_role(params = {}) ⇒ Struct
Updates an impersonation role for the given WorkMail organization.
-
#update_mailbox_quota(params = {}) ⇒ Struct
Updates a user's current mailbox quota for a specified organization and user.
-
#update_mobile_device_access_rule(params = {}) ⇒ Struct
Updates a mobile device access rule for the specified WorkMail organization.
-
#update_primary_email_address(params = {}) ⇒ Struct
Updates the primary email for a user, group, or resource.
-
#update_resource(params = {}) ⇒ Struct
Updates data for the resource.
-
#update_user(params = {}) ⇒ Struct
Updates data for the user.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-workmail/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4913 4914 4915 |
# File 'lib/aws-sdk-workmail/client.rb', line 4913 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4916 4917 4918 |
# File 'lib/aws-sdk-workmail/client.rb', line 4916 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#associate_delegate_to_resource(params = {}) ⇒ Struct
Adds a member (user or group) to the resource's set of delegates.
86 |
# File 'sig/client.rbs', line 86
def associate_delegate_to_resource: (
|
#associate_member_to_group(params = {}) ⇒ Struct
Adds a member (user or group) to the group's set.
97 |
# File 'sig/client.rbs', line 97
def associate_member_to_group: (
|
#assume_impersonation_role(params = {}) ⇒ Types::AssumeImpersonationRoleResponse
Assumes an impersonation role for the given WorkMail organization. This method returns an authentication token you can use to make impersonated calls.
110 |
# File 'sig/client.rbs', line 110
def assume_impersonation_role: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4886 4887 4888 4889 4890 4891 4892 4893 4894 4895 4896 4897 4898 4899 4900 4901 4902 |
# File 'lib/aws-sdk-workmail/client.rb', line 4886 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::WorkMail') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-workmail' context[:gem_version] = '1.103.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_mailbox_export_job(params = {}) ⇒ Struct
Cancels a mailbox export job.
120 |
# File 'sig/client.rbs', line 120
def cancel_mailbox_export_job: (
|
#create_alias(params = {}) ⇒ Struct
Adds an alias to the set of a given member (user or group) of WorkMail.
131 |
# File 'sig/client.rbs', line 131
def create_alias: (
|
#create_availability_configuration(params = {}) ⇒ Struct
Creates an AvailabilityConfiguration for the given WorkMail
organization and domain.
142 |
# File 'sig/client.rbs', line 142
def create_availability_configuration: (
|
#create_group(params = {}) ⇒ Types::CreateGroupResponse
Creates a group that can be used in WorkMail by calling the RegisterToWorkMail operation.
162 |
# File 'sig/client.rbs', line 162
def create_group: (
|
#create_identity_center_application(params = {}) ⇒ Types::CreateIdentityCenterApplicationResponse
Creates the WorkMail application in IAM Identity Center that can be used later in the WorkMail - IdC integration. For more information, see PutIdentityProviderConfiguration. This action does not affect the authentication settings for any WorkMail organizations.
174 |
# File 'sig/client.rbs', line 174
def create_identity_center_application: (
|
#create_impersonation_role(params = {}) ⇒ Types::CreateImpersonationRoleResponse
Creates an impersonation role for the given WorkMail organization.
Idempotency ensures that an API request completes no more than one time. With an idempotent request, if the original request completes successfully, any subsequent retries also complete successfully without performing any further actions.
186 |
# File 'sig/client.rbs', line 186
def create_impersonation_role: (
|
#create_mobile_device_access_rule(params = {}) ⇒ Types::CreateMobileDeviceAccessRuleResponse
Creates a new mobile device access rule for the specified WorkMail organization.
203 |
# File 'sig/client.rbs', line 203
def create_mobile_device_access_rule: (
|
#create_organization(params = {}) ⇒ Types::CreateOrganizationResponse
Creates a new WorkMail organization. Optionally, you can choose to associate an existing AWS Directory Service directory with your organization. If an AWS Directory Service directory ID is specified, the organization alias must match the directory alias. If you choose not to associate an existing directory with your organization, then we create a new WorkMail directory for you. For more information, see Adding an organization in the WorkMail Administrator Guide.
You can associate multiple email domains with an organization, then choose your default email domain from the WorkMail console. You can also associate a domain that is managed in an Amazon Route 53 public hosted zone. For more information, see Adding a domain and Choosing the default domain in the WorkMail Administrator Guide.
Optionally, you can use a customer managed key from AWS Key Management Service (AWS KMS) to encrypt email for your organization. If you don't associate an AWS KMS key, WorkMail creates a default, AWS managed key for you.
225 |
# File 'sig/client.rbs', line 225
def create_organization: (
|
#create_resource(params = {}) ⇒ Types::CreateResourceResponse
Creates a new WorkMail resource.
245 |
# File 'sig/client.rbs', line 245
def create_resource: (
|
#create_user(params = {}) ⇒ Types::CreateUserResponse
Creates a user who can be used in WorkMail by calling the RegisterToWorkMail operation.
259 |
# File 'sig/client.rbs', line 259
def create_user: (
|
#delete_access_control_rule(params = {}) ⇒ Struct
Deletes an access control rule for the specified WorkMail organization.
276 |
# File 'sig/client.rbs', line 276
def delete_access_control_rule: (
|
#delete_alias(params = {}) ⇒ Struct
Remove one or more specified aliases from a set of aliases for a given user.
286 |
# File 'sig/client.rbs', line 286
def delete_alias: (
|
#delete_availability_configuration(params = {}) ⇒ Struct
Deletes the AvailabilityConfiguration for the given WorkMail
organization and domain.
297 |
# File 'sig/client.rbs', line 297
def delete_availability_configuration: (
|
#delete_email_monitoring_configuration(params = {}) ⇒ Struct
Deletes the email monitoring configuration for a specified organization.
307 |
# File 'sig/client.rbs', line 307
def delete_email_monitoring_configuration: (
|
#delete_group(params = {}) ⇒ Struct
Deletes a group from WorkMail.
316 |
# File 'sig/client.rbs', line 316
def delete_group: (
|
#delete_identity_center_application(params = {}) ⇒ Struct
Deletes the IAM Identity Center application from WorkMail. This action does not affect the authentication settings for any WorkMail organizations.
326 |
# File 'sig/client.rbs', line 326
def delete_identity_center_application: (
|
#delete_identity_provider_configuration(params = {}) ⇒ Struct
Disables the integration between IdC and WorkMail. Authentication will continue with the directory as it was before the IdC integration. You might have to reset your directory passwords and reconfigure your desktop and mobile email clients.
335 |
# File 'sig/client.rbs', line 335
def delete_identity_provider_configuration: (
|
#delete_impersonation_role(params = {}) ⇒ Struct
Deletes an impersonation role for the given WorkMail organization.
344 |
# File 'sig/client.rbs', line 344
def delete_impersonation_role: (
|
#delete_mailbox_permissions(params = {}) ⇒ Struct
Deletes permissions granted to a member (user or group).
354 |
# File 'sig/client.rbs', line 354
def delete_mailbox_permissions: (
|
#delete_mobile_device_access_override(params = {}) ⇒ Struct
Deletes the mobile device access override for the given WorkMail organization, user, and device.
365 |
# File 'sig/client.rbs', line 365
def delete_mobile_device_access_override: (
|
#delete_mobile_device_access_rule(params = {}) ⇒ Struct
Deletes a mobile device access rule for the specified WorkMail organization.
376 |
# File 'sig/client.rbs', line 376
def delete_mobile_device_access_rule: (
|
#delete_organization(params = {}) ⇒ Types::DeleteOrganizationResponse
Deletes an WorkMail organization and all underlying AWS resources managed by WorkMail as part of the organization. You can choose whether to delete the associated directory. For more information, see Removing an organization in the WorkMail Administrator Guide.
388 |
# File 'sig/client.rbs', line 388
def delete_organization: (
|
#delete_personal_access_token(params = {}) ⇒ Struct
Deletes the Personal Access Token from the provided WorkMail Organization.
401 |
# File 'sig/client.rbs', line 401
def delete_personal_access_token: (
|
#delete_resource(params = {}) ⇒ Struct
Deletes the specified resource.
411 |
# File 'sig/client.rbs', line 411
def delete_resource: (
|
#delete_retention_policy(params = {}) ⇒ Struct
Deletes the specified retention policy from the specified organization.
421 |
# File 'sig/client.rbs', line 421
def delete_retention_policy: (
|
#delete_user(params = {}) ⇒ Struct
Deletes a user from WorkMail and all subsequent systems. Before you
can delete a user, the user state must be DISABLED. Use the
DescribeUser action to confirm the user state.
Deleting a user is permanent and cannot be undone. WorkMail archives user mailboxes for 30 days before they are permanently removed.
431 |
# File 'sig/client.rbs', line 431
def delete_user: (
|
#deregister_from_work_mail(params = {}) ⇒ Struct
Mark a user, group, or resource as no longer used in WorkMail. This action disassociates the mailbox and schedules it for clean-up. WorkMail keeps mailboxes for 30 days before they are permanently removed. The functionality in the console is Disable.
441 |
# File 'sig/client.rbs', line 441
def deregister_from_work_mail: (
|
#deregister_mail_domain(params = {}) ⇒ Struct
Removes a domain from WorkMail, stops email routing to WorkMail, and removes the authorization allowing WorkMail use. SES keeps the domain because other applications may use it. You must first remove any email address used by WorkMail entities before you remove the domain.
451 |
# File 'sig/client.rbs', line 451
def deregister_mail_domain: (
|
#describe_email_monitoring_configuration(params = {}) ⇒ Types::DescribeEmailMonitoringConfigurationResponse
Describes the current email monitoring configuration for a specified organization.
463 |
# File 'sig/client.rbs', line 463
def describe_email_monitoring_configuration: (
|
#describe_entity(params = {}) ⇒ Types::DescribeEntityResponse
Returns basic details about an entity in WorkMail.
475 |
# File 'sig/client.rbs', line 475
def describe_entity: (
|
#describe_group(params = {}) ⇒ Types::DescribeGroupResponse
Returns the data available for the group.
492 |
# File 'sig/client.rbs', line 492
def describe_group: (
|
#describe_identity_provider_configuration(params = {}) ⇒ Types::DescribeIdentityProviderConfigurationResponse
Returns detailed information on the current IdC setup for the WorkMail organization.
505 |
# File 'sig/client.rbs', line 505
def describe_identity_provider_configuration: (
|
#describe_inbound_dmarc_settings(params = {}) ⇒ Types::DescribeInboundDmarcSettingsResponse
Lists the settings in a DMARC policy for a specified organization.
515 |
# File 'sig/client.rbs', line 515
def describe_inbound_dmarc_settings: (
|
#describe_mailbox_export_job(params = {}) ⇒ Types::DescribeMailboxExportJobResponse
Describes the current status of a mailbox export job.
536 |
# File 'sig/client.rbs', line 536
def describe_mailbox_export_job: (
|
#describe_organization(params = {}) ⇒ Types::DescribeOrganizationResponse
Provides more information regarding a given organization based on its identifier.
557 |
# File 'sig/client.rbs', line 557
def describe_organization: (
|
#describe_resource(params = {}) ⇒ Types::DescribeResourceResponse
Returns the data available for the resource.
576 |
# File 'sig/client.rbs', line 576
def describe_resource: (
|
#describe_user(params = {}) ⇒ Types::DescribeUserResponse
Provides information regarding the user.
611 |
# File 'sig/client.rbs', line 611
def describe_user: (
|
#disassociate_delegate_from_resource(params = {}) ⇒ Struct
Removes a member from the resource's set of delegates.
621 |
# File 'sig/client.rbs', line 621
def disassociate_delegate_from_resource: (
|
#disassociate_member_from_group(params = {}) ⇒ Struct
Removes a member from a group.
632 |
# File 'sig/client.rbs', line 632
def disassociate_member_from_group: (
|
#get_access_control_effect(params = {}) ⇒ Types::GetAccessControlEffectResponse
Gets the effects of an organization's access control rules as they apply to a specified IPv4 address, access protocol action, and user ID or impersonation role ID. You must provide either the user ID or impersonation role ID. Impersonation role ID can only be used with Action EWS.
645 |
# File 'sig/client.rbs', line 645
def get_access_control_effect: (
|
#get_default_retention_policy(params = {}) ⇒ Types::GetDefaultRetentionPolicyResponse
Gets the default retention policy details for the specified organization.
662 |
# File 'sig/client.rbs', line 662
def get_default_retention_policy: (
|
#get_impersonation_role(params = {}) ⇒ Types::GetImpersonationRoleResponse
Gets the impersonation role details for the given WorkMail organization.
678 |
# File 'sig/client.rbs', line 678
def get_impersonation_role: (
|
#get_impersonation_role_effect(params = {}) ⇒ Types::GetImpersonationRoleEffectResponse
Tests whether the given impersonation role can impersonate a target user.
691 |
# File 'sig/client.rbs', line 691
def get_impersonation_role_effect: (
|
#get_mail_domain(params = {}) ⇒ Types::GetMailDomainResponse
Gets details for a mail domain, including domain records required to configure your domain with recommended security.
707 |
# File 'sig/client.rbs', line 707
def get_mail_domain: (
|
#get_mailbox_details(params = {}) ⇒ Types::GetMailboxDetailsResponse
Requests a user's mailbox details for a specified organization and user.
719 |
# File 'sig/client.rbs', line 719
def get_mailbox_details: (
|
#get_mobile_device_access_effect(params = {}) ⇒ Types::GetMobileDeviceAccessEffectResponse
Simulates the effect of the mobile device access rules for the given attributes of a sample access event. Use this method to test the effects of the current set of mobile device access rules for the WorkMail organization for a particular user's attributes.
731 |
# File 'sig/client.rbs', line 731
def get_mobile_device_access_effect: (
|
#get_mobile_device_access_override(params = {}) ⇒ Types::GetMobileDeviceAccessOverrideResponse
Gets the mobile device access override for the given WorkMail organization, user, and device.
750 |
# File 'sig/client.rbs', line 750
def get_mobile_device_access_override: (
|
#get_personal_access_token_metadata(params = {}) ⇒ Types::GetPersonalAccessTokenMetadataResponse
Requests details of a specific Personal Access Token within the WorkMail organization.
768 |
# File 'sig/client.rbs', line 768
def get_personal_access_token_metadata: (
|
#list_access_control_rules(params = {}) ⇒ Types::ListAccessControlRulesResponse
Lists the access control rules for the specified organization.
779 |
# File 'sig/client.rbs', line 779
def list_access_control_rules: (
|
#list_aliases(params = {}) ⇒ Types::ListAliasesResponse
Creates a paginated call to list the aliases associated with a given entity.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
790 |
# File 'sig/client.rbs', line 790
def list_aliases: (
|
#list_availability_configurations(params = {}) ⇒ Types::ListAvailabilityConfigurationsResponse
List all the AvailabilityConfiguration's for the given WorkMail
organization.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
804 |
# File 'sig/client.rbs', line 804
def list_availability_configurations: (
|
#list_group_members(params = {}) ⇒ Types::ListGroupMembersResponse
Returns an overview of the members of a group. Users and groups can be members of a group.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
817 |
# File 'sig/client.rbs', line 817
def list_group_members: (
|
#list_groups(params = {}) ⇒ Types::ListGroupsResponse
Returns summaries of the organization's groups.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
831 |
# File 'sig/client.rbs', line 831
def list_groups: (
|
#list_groups_for_entity(params = {}) ⇒ Types::ListGroupsForEntityResponse
Returns all the groups to which an entity belongs.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
849 |
# File 'sig/client.rbs', line 849
def list_groups_for_entity: (
|
#list_impersonation_roles(params = {}) ⇒ Types::ListImpersonationRolesResponse
Lists all the impersonation roles for the given WorkMail organization.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
866 |
# File 'sig/client.rbs', line 866
def list_impersonation_roles: (
|
#list_mail_domains(params = {}) ⇒ Types::ListMailDomainsResponse
Lists the mail domains in a given WorkMail organization.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
879 |
# File 'sig/client.rbs', line 879
def list_mail_domains: (
|
#list_mailbox_export_jobs(params = {}) ⇒ Types::ListMailboxExportJobsResponse
Lists the mailbox export jobs started for the specified organization within the last seven days.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
892 |
# File 'sig/client.rbs', line 892
def list_mailbox_export_jobs: (
|
#list_mailbox_permissions(params = {}) ⇒ Types::ListMailboxPermissionsResponse
Lists the mailbox permissions associated with a user, group, or resource mailbox.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
905 |
# File 'sig/client.rbs', line 905
def list_mailbox_permissions: (
|
#list_mobile_device_access_overrides(params = {}) ⇒ Types::ListMobileDeviceAccessOverridesResponse
Lists all the mobile device access overrides for any given combination of WorkMail organization, user, or device.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
919 |
# File 'sig/client.rbs', line 919
def list_mobile_device_access_overrides: (
|
#list_mobile_device_access_rules(params = {}) ⇒ Types::ListMobileDeviceAccessRulesResponse
Lists the mobile device access rules for the specified WorkMail organization.
933 |
# File 'sig/client.rbs', line 933
def list_mobile_device_access_rules: (
|
#list_organizations(params = {}) ⇒ Types::ListOrganizationsResponse
Returns summaries of the customer's organizations.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
944 |
# File 'sig/client.rbs', line 944
def list_organizations: (
|
#list_personal_access_tokens(params = {}) ⇒ Types::ListPersonalAccessTokensResponse
Returns a summary of your Personal Access Tokens.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
956 |
# File 'sig/client.rbs', line 956
def list_personal_access_tokens: (
|
#list_resource_delegates(params = {}) ⇒ Types::ListResourceDelegatesResponse
Lists the delegates associated with a resource. Users and groups can be resource delegates and answer requests on behalf of the resource.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
970 |
# File 'sig/client.rbs', line 970
def list_resource_delegates: (
|
#list_resources(params = {}) ⇒ Types::ListResourcesResponse
Returns summaries of the organization's resources.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
984 |
# File 'sig/client.rbs', line 984
def list_resources: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags applied to an WorkMail organization resource.
1001 |
# File 'sig/client.rbs', line 1001
def list_tags_for_resource: (
|
#list_users(params = {}) ⇒ Types::ListUsersResponse
Returns summaries of the organization's users.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1012 |
# File 'sig/client.rbs', line 1012
def list_users: (
|
#put_access_control_rule(params = {}) ⇒ Struct
Adds a new access control rule for the specified organization. The rule allows or denies access to the organization for the specified IPv4 addresses, access protocol actions, user IDs and impersonation IDs. Adding a new rule with the same name as an existing rule replaces the older rule.
1030 |
# File 'sig/client.rbs', line 1030
def put_access_control_rule: (
|
#put_email_monitoring_configuration(params = {}) ⇒ Struct
Creates or updates the email monitoring configuration for a specified organization.
1050 |
# File 'sig/client.rbs', line 1050
def put_email_monitoring_configuration: (
|
#put_identity_provider_configuration(params = {}) ⇒ Struct
Enables integration between IAM Identity Center (IdC) and WorkMail to proxy authentication requests for mailbox users. You can connect your IdC directory or your external directory to WorkMail through IdC and manage access to WorkMail mailboxes in a single place. For enhanced protection, you could enable Multifactor Authentication (MFA) and Personal Access Tokens.
1061 |
# File 'sig/client.rbs', line 1061
def put_identity_provider_configuration: (
|
#put_inbound_dmarc_settings(params = {}) ⇒ Struct
Enables or disables a DMARC policy for a given organization.
1079 |
# File 'sig/client.rbs', line 1079
def put_inbound_dmarc_settings: (
|
#put_mailbox_permissions(params = {}) ⇒ Struct
Sets permissions for a user, group, or resource. This replaces any pre-existing permissions.
1089 |
# File 'sig/client.rbs', line 1089
def put_mailbox_permissions: (
|
#put_mobile_device_access_override(params = {}) ⇒ Struct
Creates or updates a mobile device access override for the given WorkMail organization, user, and device.
1101 |
# File 'sig/client.rbs', line 1101
def put_mobile_device_access_override: (
|
#put_retention_policy(params = {}) ⇒ Struct
Puts a retention policy to the specified organization.
1114 |
# File 'sig/client.rbs', line 1114
def put_retention_policy: (
|
#register_mail_domain(params = {}) ⇒ Struct
Registers a new domain in WorkMail and SES, and configures it for use by WorkMail. Emails received by SES for this domain are routed to the specified WorkMail organization, and WorkMail has permanent permission to use the specified domain for sending your users' emails.
1133 |
# File 'sig/client.rbs', line 1133
def register_mail_domain: (
|
#register_to_work_mail(params = {}) ⇒ Struct
Registers an existing and disabled user, group, or resource for WorkMail use by associating a mailbox and calendaring capabilities. It performs no change if the user, group, or resource is enabled and fails if the user, group, or resource is deleted. This operation results in the accumulation of costs. For more information, see Pricing. The equivalent console functionality for this operation is Enable.
Users can either be created by calling the CreateUser API operation or they can be synchronized from your directory. For more information, see DeregisterFromWorkMail.
1144 |
# File 'sig/client.rbs', line 1144
def register_to_work_mail: (
|
#reset_password(params = {}) ⇒ Struct
Allows the administrator to reset the password for a user.
1155 |
# File 'sig/client.rbs', line 1155
def reset_password: (
|
#start_mailbox_export_job(params = {}) ⇒ Types::StartMailboxExportJobResponse
Starts a mailbox export job to export MIME-format email messages and calendar items from the specified mailbox to the specified Amazon Simple Storage Service (Amazon S3) bucket. For more information, see Exporting mailbox content in the WorkMail Administrator Guide.
1167 |
# File 'sig/client.rbs', line 1167
def start_mailbox_export_job: (
|
#tag_resource(params = {}) ⇒ Struct
Applies the specified tags to the specified WorkMailorganization resource.
1183 |
# File 'sig/client.rbs', line 1183
def tag_resource: (
|
#test_availability_configuration(params = {}) ⇒ Types::TestAvailabilityConfigurationResponse
Performs a test on an availability provider to ensure that access is
allowed. For EWS, it verifies the provided credentials can be used to
successfully log in. For Lambda, it verifies that the Lambda function
can be invoked and that the resource access policy was configured to
deny anonymous access. An anonymous invocation is one done without
providing either a SourceArn or SourceAccount header.
EwsProvider
or LambdaProvider) or the DomainName parameter. If the
DomainName parameter is provided, the configuration stored under the
DomainName will be tested.
1200 |
# File 'sig/client.rbs', line 1200
def test_availability_configuration: (
|
#untag_resource(params = {}) ⇒ Struct
Untags the specified tags from the specified WorkMail organization resource.
1218 |
# File 'sig/client.rbs', line 1218
def untag_resource: (
|
#update_availability_configuration(params = {}) ⇒ Struct
Updates an existing AvailabilityConfiguration for the given WorkMail
organization and domain.
1228 |
# File 'sig/client.rbs', line 1228
def update_availability_configuration: (
|
#update_default_mail_domain(params = {}) ⇒ Struct
Updates the default mail domain for an organization. The default mail domain is used by the WorkMail AWS Console to suggest an email address when enabling a mail user. You can only have one default domain.
1246 |
# File 'sig/client.rbs', line 1246
def update_default_mail_domain: (
|
#update_group(params = {}) ⇒ Struct
Updates attributes in a group.
1256 |
# File 'sig/client.rbs', line 1256
def update_group: (
|
#update_impersonation_role(params = {}) ⇒ Struct
Updates an impersonation role for the given WorkMail organization.
1267 |
# File 'sig/client.rbs', line 1267
def update_impersonation_role: (
|
#update_mailbox_quota(params = {}) ⇒ Struct
Updates a user's current mailbox quota for a specified organization and user.
1283 |
# File 'sig/client.rbs', line 1283
def update_mailbox_quota: (
|
#update_mobile_device_access_rule(params = {}) ⇒ Struct
Updates a mobile device access rule for the specified WorkMail organization.
1294 |
# File 'sig/client.rbs', line 1294
def update_mobile_device_access_rule: (
|
#update_primary_email_address(params = {}) ⇒ Struct
Updates the primary email for a user, group, or resource. The current email is moved into the list of aliases (or swapped between an existing alias and the current primary email), and the email provided in the input is promoted as the primary.
1315 |
# File 'sig/client.rbs', line 1315
def update_primary_email_address: (
|
#update_resource(params = {}) ⇒ Struct
Updates data for the resource. To have the latest information, it must
be preceded by a DescribeResource call. The dataset in the request
should be the one expected when performing another DescribeResource
call.
1326 |
# File 'sig/client.rbs', line 1326
def update_resource: (
|
#update_user(params = {}) ⇒ Struct
Updates data for the user. To have the latest information, it must be
preceded by a DescribeUser call. The dataset in the request should be
the one expected when performing another DescribeUser call.
1345 |
# File 'sig/client.rbs', line 1345
def update_user: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4906 4907 4908 |
# File 'lib/aws-sdk-workmail/client.rb', line 4906 def waiter_names [] end |