Class: Aws::WorkMail::Types::CreateMobileDeviceAccessRuleRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-workmail/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

The idempotency token for the client request.

A suitable default value is auto-generated. You should normally not need to pass this option.



577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
# File 'lib/aws-sdk-workmail/types.rb', line 577

class CreateMobileDeviceAccessRuleRequest < Struct.new(
  :organization_id,
  :client_token,
  :name,
  :description,
  :effect,
  :device_types,
  :not_device_types,
  :device_models,
  :not_device_models,
  :device_operating_systems,
  :not_device_operating_systems,
  :device_user_agents,
  :not_device_user_agents)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The rule description.



577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
# File 'lib/aws-sdk-workmail/types.rb', line 577

class CreateMobileDeviceAccessRuleRequest < Struct.new(
  :organization_id,
  :client_token,
  :name,
  :description,
  :effect,
  :device_types,
  :not_device_types,
  :device_models,
  :not_device_models,
  :device_operating_systems,
  :not_device_operating_systems,
  :device_user_agents,
  :not_device_user_agents)
  SENSITIVE = []
  include Aws::Structure
end

#device_modelsArray<String>

Device models that the rule will match.



577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
# File 'lib/aws-sdk-workmail/types.rb', line 577

class CreateMobileDeviceAccessRuleRequest < Struct.new(
  :organization_id,
  :client_token,
  :name,
  :description,
  :effect,
  :device_types,
  :not_device_types,
  :device_models,
  :not_device_models,
  :device_operating_systems,
  :not_device_operating_systems,
  :device_user_agents,
  :not_device_user_agents)
  SENSITIVE = []
  include Aws::Structure
end

#device_operating_systemsArray<String>

Device operating systems that the rule will match.



577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
# File 'lib/aws-sdk-workmail/types.rb', line 577

class CreateMobileDeviceAccessRuleRequest < Struct.new(
  :organization_id,
  :client_token,
  :name,
  :description,
  :effect,
  :device_types,
  :not_device_types,
  :device_models,
  :not_device_models,
  :device_operating_systems,
  :not_device_operating_systems,
  :device_user_agents,
  :not_device_user_agents)
  SENSITIVE = []
  include Aws::Structure
end

#device_typesArray<String>

Device types that the rule will match.



577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
# File 'lib/aws-sdk-workmail/types.rb', line 577

class CreateMobileDeviceAccessRuleRequest < Struct.new(
  :organization_id,
  :client_token,
  :name,
  :description,
  :effect,
  :device_types,
  :not_device_types,
  :device_models,
  :not_device_models,
  :device_operating_systems,
  :not_device_operating_systems,
  :device_user_agents,
  :not_device_user_agents)
  SENSITIVE = []
  include Aws::Structure
end

#device_user_agentsArray<String>

Device user agents that the rule will match.



577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
# File 'lib/aws-sdk-workmail/types.rb', line 577

class CreateMobileDeviceAccessRuleRequest < Struct.new(
  :organization_id,
  :client_token,
  :name,
  :description,
  :effect,
  :device_types,
  :not_device_types,
  :device_models,
  :not_device_models,
  :device_operating_systems,
  :not_device_operating_systems,
  :device_user_agents,
  :not_device_user_agents)
  SENSITIVE = []
  include Aws::Structure
end

#effectString

The effect of the rule when it matches. Allowed values are ALLOW or DENY.



577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
# File 'lib/aws-sdk-workmail/types.rb', line 577

class CreateMobileDeviceAccessRuleRequest < Struct.new(
  :organization_id,
  :client_token,
  :name,
  :description,
  :effect,
  :device_types,
  :not_device_types,
  :device_models,
  :not_device_models,
  :device_operating_systems,
  :not_device_operating_systems,
  :device_user_agents,
  :not_device_user_agents)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The rule name.



577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
# File 'lib/aws-sdk-workmail/types.rb', line 577

class CreateMobileDeviceAccessRuleRequest < Struct.new(
  :organization_id,
  :client_token,
  :name,
  :description,
  :effect,
  :device_types,
  :not_device_types,
  :device_models,
  :not_device_models,
  :device_operating_systems,
  :not_device_operating_systems,
  :device_user_agents,
  :not_device_user_agents)
  SENSITIVE = []
  include Aws::Structure
end

#not_device_modelsArray<String>

Device models that the rule will not match. All other device models will match.



577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
# File 'lib/aws-sdk-workmail/types.rb', line 577

class CreateMobileDeviceAccessRuleRequest < Struct.new(
  :organization_id,
  :client_token,
  :name,
  :description,
  :effect,
  :device_types,
  :not_device_types,
  :device_models,
  :not_device_models,
  :device_operating_systems,
  :not_device_operating_systems,
  :device_user_agents,
  :not_device_user_agents)
  SENSITIVE = []
  include Aws::Structure
end

#not_device_operating_systemsArray<String>

Device operating systems that the rule will not match. All other device operating systems will match.



577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
# File 'lib/aws-sdk-workmail/types.rb', line 577

class CreateMobileDeviceAccessRuleRequest < Struct.new(
  :organization_id,
  :client_token,
  :name,
  :description,
  :effect,
  :device_types,
  :not_device_types,
  :device_models,
  :not_device_models,
  :device_operating_systems,
  :not_device_operating_systems,
  :device_user_agents,
  :not_device_user_agents)
  SENSITIVE = []
  include Aws::Structure
end

#not_device_typesArray<String>

Device types that the rule will not match. All other device types will match.



577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
# File 'lib/aws-sdk-workmail/types.rb', line 577

class CreateMobileDeviceAccessRuleRequest < Struct.new(
  :organization_id,
  :client_token,
  :name,
  :description,
  :effect,
  :device_types,
  :not_device_types,
  :device_models,
  :not_device_models,
  :device_operating_systems,
  :not_device_operating_systems,
  :device_user_agents,
  :not_device_user_agents)
  SENSITIVE = []
  include Aws::Structure
end

#not_device_user_agentsArray<String>

Device user agents that the rule will not match. All other device user agents will match.



577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
# File 'lib/aws-sdk-workmail/types.rb', line 577

class CreateMobileDeviceAccessRuleRequest < Struct.new(
  :organization_id,
  :client_token,
  :name,
  :description,
  :effect,
  :device_types,
  :not_device_types,
  :device_models,
  :not_device_models,
  :device_operating_systems,
  :not_device_operating_systems,
  :device_user_agents,
  :not_device_user_agents)
  SENSITIVE = []
  include Aws::Structure
end

#organization_idString

The WorkMail organization under which the rule will be created.



577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
# File 'lib/aws-sdk-workmail/types.rb', line 577

class CreateMobileDeviceAccessRuleRequest < Struct.new(
  :organization_id,
  :client_token,
  :name,
  :description,
  :effect,
  :device_types,
  :not_device_types,
  :device_models,
  :not_device_models,
  :device_operating_systems,
  :not_device_operating_systems,
  :device_user_agents,
  :not_device_user_agents)
  SENSITIVE = []
  include Aws::Structure
end