Class: Aws::WorkMail::Types::GetMobileDeviceAccessEffectResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::WorkMail::Types::GetMobileDeviceAccessEffectResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-workmail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#effect ⇒ String
The effect of the simulated access,
ALLOWorDENY, after evaluating mobile device access rules in the WorkMail organization for the simulated user parameters. -
#matched_rules ⇒ Array<Types::MobileDeviceAccessMatchedRule>
A list of the rules which matched the simulated user input and produced the effect.
Instance Attribute Details
#effect ⇒ String
The effect of the simulated access, ALLOW or DENY, after evaluating mobile device access rules in the WorkMail organization for the simulated user parameters.
2566 2567 2568 2569 2570 2571 |
# File 'lib/aws-sdk-workmail/types.rb', line 2566 class GetMobileDeviceAccessEffectResponse < Struct.new( :effect, :matched_rules) SENSITIVE = [] include Aws::Structure end |
#matched_rules ⇒ Array<Types::MobileDeviceAccessMatchedRule>
A list of the rules which matched the simulated user input and produced the effect.
2566 2567 2568 2569 2570 2571 |
# File 'lib/aws-sdk-workmail/types.rb', line 2566 class GetMobileDeviceAccessEffectResponse < Struct.new( :effect, :matched_rules) SENSITIVE = [] include Aws::Structure end |