Class: Aws::WorkMail::Types::PutMobileDeviceAccessOverrideRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::WorkMail::Types::PutMobileDeviceAccessOverrideRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-workmail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
A description of the override.
-
#device_id ⇒ String
The mobile device for which you create the override.
-
#effect ⇒ String
The effect of the override,
ALLOWorDENY. -
#organization_id ⇒ String
Identifies the WorkMail organization for which you create the override.
-
#user_id ⇒ String
The WorkMail user for which you create the override.
Instance Attribute Details
#description ⇒ String
A description of the override.
4606 4607 4608 4609 4610 4611 4612 4613 4614 |
# File 'lib/aws-sdk-workmail/types.rb', line 4606 class PutMobileDeviceAccessOverrideRequest < Struct.new( :organization_id, :user_id, :device_id, :effect, :description) SENSITIVE = [] include Aws::Structure end |
#device_id ⇒ String
The mobile device for which you create the override. DeviceId is case insensitive.
4606 4607 4608 4609 4610 4611 4612 4613 4614 |
# File 'lib/aws-sdk-workmail/types.rb', line 4606 class PutMobileDeviceAccessOverrideRequest < Struct.new( :organization_id, :user_id, :device_id, :effect, :description) SENSITIVE = [] include Aws::Structure end |
#effect ⇒ String
The effect of the override, ALLOW or DENY.
4606 4607 4608 4609 4610 4611 4612 4613 4614 |
# File 'lib/aws-sdk-workmail/types.rb', line 4606 class PutMobileDeviceAccessOverrideRequest < Struct.new( :organization_id, :user_id, :device_id, :effect, :description) SENSITIVE = [] include Aws::Structure end |
#organization_id ⇒ String
Identifies the WorkMail organization for which you create the override.
4606 4607 4608 4609 4610 4611 4612 4613 4614 |
# File 'lib/aws-sdk-workmail/types.rb', line 4606 class PutMobileDeviceAccessOverrideRequest < Struct.new( :organization_id, :user_id, :device_id, :effect, :description) SENSITIVE = [] include Aws::Structure end |
#user_id ⇒ String
The WorkMail user for which you create the override. Accepts the following types of user identities:
-
User ID:
12345678-1234-1234-1234-123456789012orS-1-1-12-1234567890-123456789-123456789-1234 -
Email address: ‘[email protected]`
-
User name:
user
4606 4607 4608 4609 4610 4611 4612 4613 4614 |
# File 'lib/aws-sdk-workmail/types.rb', line 4606 class PutMobileDeviceAccessOverrideRequest < Struct.new( :organization_id, :user_id, :device_id, :effect, :description) SENSITIVE = [] include Aws::Structure end |