Class: Aws::WorkMail::Types::CreateMobileDeviceAccessRuleRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::WorkMail::Types::CreateMobileDeviceAccessRuleRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-workmail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
The idempotency token for the client request.
-
#description ⇒ String
The rule description.
-
#device_models ⇒ Array<String>
Device models that the rule will match.
-
#device_operating_systems ⇒ Array<String>
Device operating systems that the rule will match.
-
#device_types ⇒ Array<String>
Device types that the rule will match.
-
#device_user_agents ⇒ Array<String>
Device user agents that the rule will match.
-
#effect ⇒ String
The effect of the rule when it matches.
-
#name ⇒ String
The rule name.
-
#not_device_models ⇒ Array<String>
Device models that the rule **will not** match.
-
#not_device_operating_systems ⇒ Array<String>
Device operating systems that the rule **will not** match.
-
#not_device_types ⇒ Array<String>
Device types that the rule **will not** match.
-
#not_device_user_agents ⇒ Array<String>
Device user agents that the rule **will not** match.
-
#organization_id ⇒ String
The WorkMail organization under which the rule will be created.
Instance Attribute Details
#client_token ⇒ String
The idempotency token for the client request.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 |
# File 'lib/aws-sdk-workmail/types.rb', line 577 class CreateMobileDeviceAccessRuleRequest < Struct.new( :organization_id, :client_token, :name, :description, :effect, :device_types, :not_device_types, :device_models, :not_device_models, :device_operating_systems, :not_device_operating_systems, :device_user_agents, :not_device_user_agents) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The rule description.
577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 |
# File 'lib/aws-sdk-workmail/types.rb', line 577 class CreateMobileDeviceAccessRuleRequest < Struct.new( :organization_id, :client_token, :name, :description, :effect, :device_types, :not_device_types, :device_models, :not_device_models, :device_operating_systems, :not_device_operating_systems, :device_user_agents, :not_device_user_agents) SENSITIVE = [] include Aws::Structure end |
#device_models ⇒ Array<String>
Device models that the rule will match.
577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 |
# File 'lib/aws-sdk-workmail/types.rb', line 577 class CreateMobileDeviceAccessRuleRequest < Struct.new( :organization_id, :client_token, :name, :description, :effect, :device_types, :not_device_types, :device_models, :not_device_models, :device_operating_systems, :not_device_operating_systems, :device_user_agents, :not_device_user_agents) SENSITIVE = [] include Aws::Structure end |
#device_operating_systems ⇒ Array<String>
Device operating systems that the rule will match.
577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 |
# File 'lib/aws-sdk-workmail/types.rb', line 577 class CreateMobileDeviceAccessRuleRequest < Struct.new( :organization_id, :client_token, :name, :description, :effect, :device_types, :not_device_types, :device_models, :not_device_models, :device_operating_systems, :not_device_operating_systems, :device_user_agents, :not_device_user_agents) SENSITIVE = [] include Aws::Structure end |
#device_types ⇒ Array<String>
Device types that the rule will match.
577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 |
# File 'lib/aws-sdk-workmail/types.rb', line 577 class CreateMobileDeviceAccessRuleRequest < Struct.new( :organization_id, :client_token, :name, :description, :effect, :device_types, :not_device_types, :device_models, :not_device_models, :device_operating_systems, :not_device_operating_systems, :device_user_agents, :not_device_user_agents) SENSITIVE = [] include Aws::Structure end |
#device_user_agents ⇒ Array<String>
Device user agents that the rule will match.
577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 |
# File 'lib/aws-sdk-workmail/types.rb', line 577 class CreateMobileDeviceAccessRuleRequest < Struct.new( :organization_id, :client_token, :name, :description, :effect, :device_types, :not_device_types, :device_models, :not_device_models, :device_operating_systems, :not_device_operating_systems, :device_user_agents, :not_device_user_agents) SENSITIVE = [] include Aws::Structure end |
#effect ⇒ String
The effect of the rule when it matches. Allowed values are ALLOW or DENY.
577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 |
# File 'lib/aws-sdk-workmail/types.rb', line 577 class CreateMobileDeviceAccessRuleRequest < Struct.new( :organization_id, :client_token, :name, :description, :effect, :device_types, :not_device_types, :device_models, :not_device_models, :device_operating_systems, :not_device_operating_systems, :device_user_agents, :not_device_user_agents) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The rule name.
577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 |
# File 'lib/aws-sdk-workmail/types.rb', line 577 class CreateMobileDeviceAccessRuleRequest < Struct.new( :organization_id, :client_token, :name, :description, :effect, :device_types, :not_device_types, :device_models, :not_device_models, :device_operating_systems, :not_device_operating_systems, :device_user_agents, :not_device_user_agents) SENSITIVE = [] include Aws::Structure end |
#not_device_models ⇒ Array<String>
Device models that the rule **will not** match. All other device models will match.
577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 |
# File 'lib/aws-sdk-workmail/types.rb', line 577 class CreateMobileDeviceAccessRuleRequest < Struct.new( :organization_id, :client_token, :name, :description, :effect, :device_types, :not_device_types, :device_models, :not_device_models, :device_operating_systems, :not_device_operating_systems, :device_user_agents, :not_device_user_agents) SENSITIVE = [] include Aws::Structure end |
#not_device_operating_systems ⇒ Array<String>
Device operating systems that the rule **will not** match. All other device operating systems will match.
577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 |
# File 'lib/aws-sdk-workmail/types.rb', line 577 class CreateMobileDeviceAccessRuleRequest < Struct.new( :organization_id, :client_token, :name, :description, :effect, :device_types, :not_device_types, :device_models, :not_device_models, :device_operating_systems, :not_device_operating_systems, :device_user_agents, :not_device_user_agents) SENSITIVE = [] include Aws::Structure end |
#not_device_types ⇒ Array<String>
Device types that the rule **will not** match. All other device types will match.
577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 |
# File 'lib/aws-sdk-workmail/types.rb', line 577 class CreateMobileDeviceAccessRuleRequest < Struct.new( :organization_id, :client_token, :name, :description, :effect, :device_types, :not_device_types, :device_models, :not_device_models, :device_operating_systems, :not_device_operating_systems, :device_user_agents, :not_device_user_agents) SENSITIVE = [] include Aws::Structure end |
#not_device_user_agents ⇒ Array<String>
Device user agents that the rule **will not** match. All other device user agents will match.
577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 |
# File 'lib/aws-sdk-workmail/types.rb', line 577 class CreateMobileDeviceAccessRuleRequest < Struct.new( :organization_id, :client_token, :name, :description, :effect, :device_types, :not_device_types, :device_models, :not_device_models, :device_operating_systems, :not_device_operating_systems, :device_user_agents, :not_device_user_agents) SENSITIVE = [] include Aws::Structure end |
#organization_id ⇒ String
The WorkMail organization under which the rule will be created.
577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 |
# File 'lib/aws-sdk-workmail/types.rb', line 577 class CreateMobileDeviceAccessRuleRequest < Struct.new( :organization_id, :client_token, :name, :description, :effect, :device_types, :not_device_types, :device_models, :not_device_models, :device_operating_systems, :not_device_operating_systems, :device_user_agents, :not_device_user_agents) SENSITIVE = [] include Aws::Structure end |