Class: Aws::WorkMail::Types::UpdateMobileDeviceAccessRuleRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::WorkMail::Types::UpdateMobileDeviceAccessRuleRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-workmail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
The updated rule description.
-
#device_models ⇒ Array<String>
Device models that the updated rule will match.
-
#device_operating_systems ⇒ Array<String>
Device operating systems that the updated rule will match.
-
#device_types ⇒ Array<String>
Device types that the updated rule will match.
-
#device_user_agents ⇒ Array<String>
User agents that the updated rule will match.
-
#effect ⇒ String
The effect of the rule when it matches.
-
#mobile_device_access_rule_id ⇒ String
The identifier of the rule to be updated.
-
#name ⇒ String
The updated rule name.
-
#not_device_models ⇒ Array<String>
Device models that the updated rule **will not** match.
-
#not_device_operating_systems ⇒ Array<String>
Device operating systems that the updated rule **will not** match.
-
#not_device_types ⇒ Array<String>
Device types that the updated rule **will not** match.
-
#not_device_user_agents ⇒ Array<String>
User agents that the updated rule **will not** match.
-
#organization_id ⇒ String
The WorkMail organization under which the rule will be updated.
Instance Attribute Details
#description ⇒ String
The updated rule description.
5292 5293 5294 5295 5296 5297 5298 5299 5300 5301 5302 5303 5304 5305 5306 5307 5308 |
# File 'lib/aws-sdk-workmail/types.rb', line 5292 class UpdateMobileDeviceAccessRuleRequest < Struct.new( :organization_id, :mobile_device_access_rule_id, :name, :description, :effect, :device_types, :not_device_types, :device_models, :not_device_models, :device_operating_systems, :not_device_operating_systems, :device_user_agents, :not_device_user_agents) SENSITIVE = [] include Aws::Structure end |
#device_models ⇒ Array<String>
Device models that the updated rule will match.
5292 5293 5294 5295 5296 5297 5298 5299 5300 5301 5302 5303 5304 5305 5306 5307 5308 |
# File 'lib/aws-sdk-workmail/types.rb', line 5292 class UpdateMobileDeviceAccessRuleRequest < Struct.new( :organization_id, :mobile_device_access_rule_id, :name, :description, :effect, :device_types, :not_device_types, :device_models, :not_device_models, :device_operating_systems, :not_device_operating_systems, :device_user_agents, :not_device_user_agents) SENSITIVE = [] include Aws::Structure end |
#device_operating_systems ⇒ Array<String>
Device operating systems that the updated rule will match.
5292 5293 5294 5295 5296 5297 5298 5299 5300 5301 5302 5303 5304 5305 5306 5307 5308 |
# File 'lib/aws-sdk-workmail/types.rb', line 5292 class UpdateMobileDeviceAccessRuleRequest < Struct.new( :organization_id, :mobile_device_access_rule_id, :name, :description, :effect, :device_types, :not_device_types, :device_models, :not_device_models, :device_operating_systems, :not_device_operating_systems, :device_user_agents, :not_device_user_agents) SENSITIVE = [] include Aws::Structure end |
#device_types ⇒ Array<String>
Device types that the updated rule will match.
5292 5293 5294 5295 5296 5297 5298 5299 5300 5301 5302 5303 5304 5305 5306 5307 5308 |
# File 'lib/aws-sdk-workmail/types.rb', line 5292 class UpdateMobileDeviceAccessRuleRequest < Struct.new( :organization_id, :mobile_device_access_rule_id, :name, :description, :effect, :device_types, :not_device_types, :device_models, :not_device_models, :device_operating_systems, :not_device_operating_systems, :device_user_agents, :not_device_user_agents) SENSITIVE = [] include Aws::Structure end |
#device_user_agents ⇒ Array<String>
User agents that the updated rule will match.
5292 5293 5294 5295 5296 5297 5298 5299 5300 5301 5302 5303 5304 5305 5306 5307 5308 |
# File 'lib/aws-sdk-workmail/types.rb', line 5292 class UpdateMobileDeviceAccessRuleRequest < Struct.new( :organization_id, :mobile_device_access_rule_id, :name, :description, :effect, :device_types, :not_device_types, :device_models, :not_device_models, :device_operating_systems, :not_device_operating_systems, :device_user_agents, :not_device_user_agents) SENSITIVE = [] include Aws::Structure end |
#effect ⇒ String
The effect of the rule when it matches. Allowed values are ALLOW or DENY.
5292 5293 5294 5295 5296 5297 5298 5299 5300 5301 5302 5303 5304 5305 5306 5307 5308 |
# File 'lib/aws-sdk-workmail/types.rb', line 5292 class UpdateMobileDeviceAccessRuleRequest < Struct.new( :organization_id, :mobile_device_access_rule_id, :name, :description, :effect, :device_types, :not_device_types, :device_models, :not_device_models, :device_operating_systems, :not_device_operating_systems, :device_user_agents, :not_device_user_agents) SENSITIVE = [] include Aws::Structure end |
#mobile_device_access_rule_id ⇒ String
The identifier of the rule to be updated.
5292 5293 5294 5295 5296 5297 5298 5299 5300 5301 5302 5303 5304 5305 5306 5307 5308 |
# File 'lib/aws-sdk-workmail/types.rb', line 5292 class UpdateMobileDeviceAccessRuleRequest < Struct.new( :organization_id, :mobile_device_access_rule_id, :name, :description, :effect, :device_types, :not_device_types, :device_models, :not_device_models, :device_operating_systems, :not_device_operating_systems, :device_user_agents, :not_device_user_agents) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The updated rule name.
5292 5293 5294 5295 5296 5297 5298 5299 5300 5301 5302 5303 5304 5305 5306 5307 5308 |
# File 'lib/aws-sdk-workmail/types.rb', line 5292 class UpdateMobileDeviceAccessRuleRequest < Struct.new( :organization_id, :mobile_device_access_rule_id, :name, :description, :effect, :device_types, :not_device_types, :device_models, :not_device_models, :device_operating_systems, :not_device_operating_systems, :device_user_agents, :not_device_user_agents) SENSITIVE = [] include Aws::Structure end |
#not_device_models ⇒ Array<String>
Device models that the updated rule **will not** match. All other device models will match.
5292 5293 5294 5295 5296 5297 5298 5299 5300 5301 5302 5303 5304 5305 5306 5307 5308 |
# File 'lib/aws-sdk-workmail/types.rb', line 5292 class UpdateMobileDeviceAccessRuleRequest < Struct.new( :organization_id, :mobile_device_access_rule_id, :name, :description, :effect, :device_types, :not_device_types, :device_models, :not_device_models, :device_operating_systems, :not_device_operating_systems, :device_user_agents, :not_device_user_agents) SENSITIVE = [] include Aws::Structure end |
#not_device_operating_systems ⇒ Array<String>
Device operating systems that the updated rule **will not** match. All other device operating systems will match.
5292 5293 5294 5295 5296 5297 5298 5299 5300 5301 5302 5303 5304 5305 5306 5307 5308 |
# File 'lib/aws-sdk-workmail/types.rb', line 5292 class UpdateMobileDeviceAccessRuleRequest < Struct.new( :organization_id, :mobile_device_access_rule_id, :name, :description, :effect, :device_types, :not_device_types, :device_models, :not_device_models, :device_operating_systems, :not_device_operating_systems, :device_user_agents, :not_device_user_agents) SENSITIVE = [] include Aws::Structure end |
#not_device_types ⇒ Array<String>
Device types that the updated rule **will not** match. All other device types will match.
5292 5293 5294 5295 5296 5297 5298 5299 5300 5301 5302 5303 5304 5305 5306 5307 5308 |
# File 'lib/aws-sdk-workmail/types.rb', line 5292 class UpdateMobileDeviceAccessRuleRequest < Struct.new( :organization_id, :mobile_device_access_rule_id, :name, :description, :effect, :device_types, :not_device_types, :device_models, :not_device_models, :device_operating_systems, :not_device_operating_systems, :device_user_agents, :not_device_user_agents) SENSITIVE = [] include Aws::Structure end |
#not_device_user_agents ⇒ Array<String>
User agents that the updated rule **will not** match. All other user agents will match.
5292 5293 5294 5295 5296 5297 5298 5299 5300 5301 5302 5303 5304 5305 5306 5307 5308 |
# File 'lib/aws-sdk-workmail/types.rb', line 5292 class UpdateMobileDeviceAccessRuleRequest < Struct.new( :organization_id, :mobile_device_access_rule_id, :name, :description, :effect, :device_types, :not_device_types, :device_models, :not_device_models, :device_operating_systems, :not_device_operating_systems, :device_user_agents, :not_device_user_agents) SENSITIVE = [] include Aws::Structure end |
#organization_id ⇒ String
The WorkMail organization under which the rule will be updated.
5292 5293 5294 5295 5296 5297 5298 5299 5300 5301 5302 5303 5304 5305 5306 5307 5308 |
# File 'lib/aws-sdk-workmail/types.rb', line 5292 class UpdateMobileDeviceAccessRuleRequest < Struct.new( :organization_id, :mobile_device_access_rule_id, :name, :description, :effect, :device_types, :not_device_types, :device_models, :not_device_models, :device_operating_systems, :not_device_operating_systems, :device_user_agents, :not_device_user_agents) SENSITIVE = [] include Aws::Structure end |